Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1055)

Unified Diff: src/gpu/gl/GrGLProgramDesc.h

Issue 858343002: Rename GrOptDrawState to GrPipeline and GrDrawState to GrPipelineBuilder (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: more nits Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/gl/GrGLProgram.cpp ('k') | src/gpu/gl/GrGLProgramDesc.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/gl/GrGLProgramDesc.h
diff --git a/src/gpu/gl/GrGLProgramDesc.h b/src/gpu/gl/GrGLProgramDesc.h
index 0584082a83fb6dbf8a2350e0a528e37c270860a2..e4db4c3581ce8a81195af0eaeee35b0fbd568fb5 100644
--- a/src/gpu/gl/GrGLProgramDesc.h
+++ b/src/gpu/gl/GrGLProgramDesc.h
@@ -42,7 +42,7 @@ public:
* Builds a GL specific program descriptor
*
* @param GrPrimitiveProcessor The geometry
* @param GrOptDrawState The optimized drawstate. The descriptor will represent a program
* which this optstate can use to draw with. The optstate contains
* general draw information, as well as the specific color, geometry,
* and coverage stages which will be used to generate the GL Program for
@@ -57,7 +57,7 @@ public:
**/
static bool Build(GrProgramDesc*,
const GrPrimitiveProcessor&,
- const GrOptDrawState&,
+ const GrPipeline&,
const GrProgramDesc::DescInfo&,
const GrGLGpu*,
const GrBatchTracker&);
@@ -42,7 +42,7 @@ public:
*
* @param GrPrimitiveProcessor The geometry
- * @param GrOptDrawState The optimized drawstate. The descriptor will represent a program
+ * @param GrPipeline The optimized drawstate. The descriptor will represent a program
* which this optstate can use to draw with. The optstate contains
* general draw information, as well as the specific color, geometry,
« no previous file with comments | « src/gpu/gl/GrGLProgram.cpp ('k') | src/gpu/gl/GrGLProgramDesc.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698